@@ -84,11 +84,8 @@ public enum OptionsProperty implements Property {
     }
 
     @Override
-    public <T> T getDefaultValue(Class<T> cls) {
-        if (defaultValue.getClass().isAssignableFrom(cls)) {
-            return cls.cast(defaultValue);
-        }
-        throw new IllegalArgumentException("The object cannot be converted to the specified type '" + cls.getCanonicalName() + "'");
+    public Object getDefaultValue() {
+        return defaultValue;
     }
 
 }
