@@ -170,7 +170,7 @@ public abstract class AbstractMailFilterServlet extends HttpServlet {
             String secret = SessionUtility.extractSecret(hashSource, req, session);
             if (!session.getSecret().equals(secret)) {
                 LOG.info("Session secret is different. Given secret \"{}\" differs from secret in session \"{}\".", secret, session.getSecret());
-                throw SessionExceptionCodes.WRONG_SESSION_SECRET.create();
+                throw SessionExceptionCodes.SESSION_EXPIRED.create(sessionId);
             }
             checkMailfilterAvailable(session);
 
@@ -194,7 +194,11 @@ public abstract class AbstractMailFilterServlet extends HttpServlet {
             final AbstractAction action = getAction();
             response.setData(action.action(request));
         } catch (final OXException e) {
-            LOG.error("", e);
+            if (SessionExceptionCodes.hasPrefix(e)) {
+                LOG.debug("", e);
+            } else {
+                LOG.error("", e);
+            }
             response.setException(e);
         }
         /*
@@ -239,7 +243,7 @@ public abstract class AbstractMailFilterServlet extends HttpServlet {
             String secret = SessionUtility.extractSecret(hashSource, req, session);
             if (!session.getSecret().equals(secret)) {
                 LOG.info("Session secret is different. Given secret \"{}\" differs from secret in session \"{}\".", secret, session.getSecret());
-                throw SessionExceptionCodes.WRONG_SESSION_SECRET.create();
+                throw SessionExceptionCodes.SESSION_EXPIRED.create();
             }
             checkMailfilterAvailable(session);
 
@@ -260,7 +264,11 @@ public abstract class AbstractMailFilterServlet extends HttpServlet {
             final AbstractAction action = getAction();
             response.setData(action.action(request));
         } catch (final OXException e) {
-            LOG.error("", e);
+            if (SessionExceptionCodes.hasPrefix(e)) {
+                LOG.debug("", e);
+            } else {
+                LOG.error("", e);
+            }
             response.setException(e);
         }
         /*
