@@ -183,10 +183,6 @@ public enum MailFilterExceptionCode implements DisplayableOXExceptionCode {
      * Invalid SIEVE rule specified. Server response: %1$s
      */
     INVALID_SIEVE_RULE2("Invalid SIEVE rule specified. Server response: %1$s", INVALID_SIEVE_RULE2_MSG, CATEGORY_USER_INPUT, 25), // Yup, the same error code
-    /**
-     * Invalid SIEVE rule specified. Server response: %1$s
-     */
-    INVALID_SIEVE_RULE3("Invalid SIEVE rule specified. The provided 'from' address contains an invalid mail address. Only the users email addresses and its aliases are allowed.", INVALID_SIEVE_RULE_MSG, CATEGORY_USER_INPUT, 25), // Yup, the same error code
     /**
      * Invalid credentials
      */
@@ -219,6 +215,14 @@ public enum MailFilterExceptionCode implements DisplayableOXExceptionCode {
      * "The maximum amount of redirect rules is reached. Please delete or deactivate another redirect rule first."
      */
     TOO_MANY_REDIRECT(MailFilterExceptionMessages.TOO_MANY_REDIRECT_MSG, MailFilterExceptionMessages.TOO_MANY_REDIRECT_MSG, CATEGORY_USER_INPUT, 33),
+    /**
+     * Unable to extract a valid sieve server URI from the user's mail server URL.
+     */
+    UNABLE_TO_EXTRACT_SIEVE_SERVER_URI("Unable to extract a valid sieve server URI from the user's mail server URL.", CATEGORY_ERROR, 34),
+    /**
+     * Invalid mail filter request. A guest user has no mail filters.
+     */
+    INVALID_USER_SPECIFIED("Invalid mail filter request. A guest user has no mail filters.", CATEGORY_ERROR, 35),
     ;
 
     private final String message;
